.. python-copr documentation master file, created by
   sphinx-quickstart on Thu Sep  4 16:44:28 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

About
=====

Schema definitions for messages sent by `Copr build system`_, and several
convenience classes/methods to make the message consuming easier.

.. toctree::
   :caption: Contents:

   installation
   consuming
   api



Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


.. _`Copr build system`: https://pagure.io/copr/copr
